Validation Module
=================

.. autofunction:: validation.validate_trajectory

.. autofunction:: validation.validate_numeric_list

.. autofunction:: validation.validate_scalar

.. autofunction:: validation.validate_positive_scalar

.. autofunction:: validation.validate_distance_parameters

.. autofunction:: validation.validate_dtw

.. autofunction:: validation.validate_ers

.. autofunction:: validation.validate_erp

.. autofunction:: validation.validate_euclidean

.. autofunction:: validation.validate_frechet

.. autofunction:: validation.validate_hausdorff

.. autofunction:: validation.validate_lcss

.. autofunction:: validation.validate_rdp
